
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "EKGhfilter.h"

// ----------------------------------------------------------------------
//
// Implementation EKGdevice
// 
// ----------------------------------------------------------------------


/*
 * Der Hochpafilter besteht aus einem Tiefpafilter, dessen Ausgangswert
 * vom Signal abgezogen wird.
 */
void EKGhfilter::input( float * d )
{
  if ( ! enable ) { EKGfilter::input(d); return; }
  for ( int i = 0; i < 3; i++ )
  {
    Ha[i] += Ht * ( d[i] - Ha[i] );
    d[i] -= Ha[i];
  }
  // Daten an nchstes Gert weitergeben. 
  EKGfilter::input( d );
}


// ----------------------------------------------------------------------
//
// public Methoden
// 
// ----------------------------------------------------------------------

/*
 * Zeitkonstante fr Hochpafilter setzen.
 */
float EKGhfilter::setHTimeConstant( float x )
{
  if ( x < EKG_TimeStep ) throw 
      string("EKGhfilter::setHTimeConstant : decay time must be > EKG_TimeStep");
  float old = getHTimeConstant();
  Ht = EKG_TimeStep / x;
  return old;
}


