
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003, 2011 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef GEKG_H
#define GEKG_H

#include <pstreams/pstream.h>  // see http://pstreams.sourceforge.net/ 
#include <unistd.h>
#include <signal.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <iostream>
#include <fstream>
#include <bits/ios_base.h>
#include <ext/stdio_filebuf.h>
#include <gtkmm.h>
#include "EKGsource.h"
#include "gEKGfreq.h"
#include "gEKGdisplay.h"
#include "EKGplotter.h"
#include "EKGhfilter.h"
#include "EKGlfilter.h"
#include "gEKGPrintDialog.h"
#include "gEKGFilterDialog.h"
#include "gEKGhelp.h"
using namespace std;
using sigc::slot;


/**
 * Graphisches EKG Gert. 
 * Aufruf: <tt><strong>gEKG /dev/ttySx</strong></tt>
 */
class gEKG : public Gtk::Window
{
  public:
    /** Konstruktor */
    gEKG( const char * ttyName );
  private:
    // 
    // sichtbare Objekte
    //

    Gtk::VBox		MainBox;
    Gtk::HBox		UpperBox;
    Gtk::ToggleButton	StartButton;
    Gtk::Button		PrintButton;
    Gtk::Button		FilterButton;
    Gtk::Button		HelpButton;
    gEKGfreq 		Freq;
    Gtk::Frame 		DisplayFrame;
    Gtk::HBox 		FrameBox;
    Gtk::VBox		LabelBox;
    Gtk::Label		Label_I;
    Gtk::Label		Label_II;
    Gtk::Label		Label_III;
    Gtk::Label		Label_aVR;
    Gtk::Label		Label_aVL;
    Gtk::Label		Label_aVF;
    Gtk::EventBox	ebox_I;
    Gtk::EventBox	ebox_II;
    Gtk::EventBox	ebox_III;
    Gtk::EventBox	ebox_aVR;
    Gtk::EventBox	ebox_aVL;
    Gtk::EventBox	ebox_aVF;
    gEKGdisplay 	Display;
    gEKGPrintDialog	PrintDialog;
    gEKGFilterDialog	FilterDialog;
    gEKGhelp		HelpDialog;
    //
    // unsichtbare Objekte
    //

    EKGsource Source;
    EKGlfilter lFilter;
    EKGhfilter hFilter;
    EKGbuffer Buffer;
    Gtk::Tooltips Tips;

    //
    // Callback Methoden
    //
    
    /** 
     * Startet und beendet Messung. Vor dem Start bekommt das Display
     * einen Reset, nach dem Beenden bekommt der Pulszhler mFreq einen
     * reset.
     */
    void startCallback();
    /**
     * Druck Button. ffnet das Fenster. Gedruckt wird in
     * printDialogCallback()
     */
    void printCallback();
    /// PrinterDialog OKButton. Hier wird gedruckt.
    void printDialogCallback();
    /// ffnet den Filterdialog
    void filterCallback();
    /// Filtereinstellungen werden bernommen
    void filterApplyCallback();
    /// Hilfe ffnen
    void helpCallback() { HelpDialog.show(); }
    /** 
     * Nimmt Tastendrcke entgegen und verarbeitet sie.
     * Tastarurbelegung:
     * <code>
     * space     - Start/Stop
     *   q       - Beenden
     * p / Druck - Drucken
     * </code>
     */
    gint keyCallback( GdkEventKey * e );
};

#endif

