
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003, 2011 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef GEKGFILTERDIALOG_H
#define GEKGFILTERDIALOG_H
#include <gtkmm.h>
#include "calibrate.h"
using namespace std;
using sigc::slot;


/**
 * Dialogfenster zum einstellen der Filter. 
 */
class gEKGFilterDialog : public Gtk::Dialog
{
public:
  /// Konstruktor
  gEKGFilterDialog();

  /**
   * Setzen aller Werte.
   * @param low Tiefpass eingeschaltet
   * @param lowVal Teifpass Grenzfrequenz
   * @param high Hochpass eingeschaltet
   * @param highVal Hochpass Zeitkonstante
   */
  void setValues( bool low, float lowVal, bool high, float highVal );
  /// Tiefpass eingeschaltet
  bool getLow() const { return LowCheck.get_active(); }
  /// Teifpass Grenzfrequenz
  double getLowVal() const { return LowSpin->get_value(); }
  /// Hochpass eingeschaltet
  bool getHigh() const { return HighCheck.get_active(); }
  /// Hochpass Zeitkonstante
  double getHighVal() const { return HighSpin->get_value(); }

  /// OK Button
  Gtk::Button OKButton;
  /// Apply Button
  Gtk::Button AButton;
  /// Cancel Button
  Gtk::Button CButton;
private:
  //
  // Gtk Elemente mit ffentlichem Inhalt
  //
 
  /// Tiefpass aktiviert
  Gtk::CheckButton LowCheck;
  /// Hochpass aktiviert
  Gtk::CheckButton HighCheck;
  /// Frequenz Tiefpass
  Gtk::SpinButton * LowSpin;
  /// Frequenz Hochpass
  Gtk::SpinButton * HighSpin;

  //
  // Gtk Elemente ohne Inhalt
  //

  /// Buttons im unteren Teil
  Gtk::HButtonBox bBox;
  /// Ausrichtung oben
  Gtk::Table table;
  /// Label ,,Frequenz''
  Gtk::Label LowLabel;
  /// Lable ,,Time Constant''
  Gtk::Label HighLabel;
  /// Strich in der Mitte
  Gtk::HSeparator separator;

  //
  // Event Handler
  //
  
  /// Auf Knopfdruck verschwindet das Fenster
  void buttonCallback() { hide(); }
  /// Tastendrcke
  gint keyCallback( GdkEventKey * e );
  /// Fenster wird beim schlieen nicht zerstrt.
  int delete_event_impl(GdkEventAny *event) 
    { buttonCallback(); return true; }

}; 

#endif
