
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003, 2011 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "gEKGPrintDialog.h"

gEKGPrintDialog::gEKGPrintDialog() : 
				     tfCButton( "Print to File" ),
                                     OKButton( "OK" ), 
				     CButton( "Cancel" ),
				     tLabel( "Time Scale: ", 0, 0 ),
				     vLabel( "Voltage Scale: ", 0, 0 ),
				     nLabel( "Print Cmd/File: ", 0, 0 ),
				     pnLabel( "Patient: ", 0, 0 ),
				     pdLabel( "Day of Birth: ", 0, 0 ),
				     bBox( Gtk::BUTTONBOX_EDGE, 10 ),
				     table( 6, 2, false )
{
  // init times
  tCombo.append_text("50 mm/s");
  tCombo.append_text("25 mm/s");
  tCombo.append_text("10 mm/s");
  tCombo.append_text("5 mm/s");
  tCombo.set_active( 0 );
  // init voltage
  vCombo.append_text("20 mm/mV");
  vCombo.append_text("10 mm/mV");
  vCombo.append_text("5 mm/mV");
  vCombo.append_text("2.5 mm/mV");
  vCombo.set_active( 0 );
  // init Patienten Name
  struct passwd * pw = getpwuid( geteuid() );
  string my_pname( pw->pw_name );
  pName.set_text( my_pname );
  // init Filename
  fName.set_text( "lpr" );
  // Aussehen oben
  Gtk::VBox * top = get_vbox();
  table.set_row_spacings( 8 );
  table.attach( pnLabel,	0, 1, 0, 1 );
  table.attach(  pName,		1, 2, 0, 1 );
  table.attach( pdLabel,	0, 1, 1, 2 );
  table.attach(  pDate,		1, 2, 1, 2 );
  table.attach( separator,	0, 2, 2, 3 );
  table.attach(  tLabel,	0, 1, 3, 4 );
  table.attach(  tCombo,	1, 2, 3, 4 );
  table.attach(  vLabel,	0, 1, 4, 5 );
  table.attach(  vCombo,	1, 2, 4, 5 );
  table.attach(  nLabel,	0, 1, 5, 6 );
  table.attach(  fName,		1, 2, 5, 6 );
  table.attach( tfCButton,	0, 2, 6, 7 );
  top->pack_start( table, false, false, 0 );
  // Aussehen unten
  Gtk::ButtonBox * bottom = get_action_area();
  bBox.pack_start( OKButton );
  bBox.pack_start( CButton );
  bottom->pack_start( bBox );
  // Aussehen allgemein
  set_wmclass( "EKG", "EKG" );
  set_title( "Print EKG" );
  // TODO set_policy( false, false, true );
  set_border_width( 5 );
  // Event Handler
  OKButton.signal_clicked().connect(
    mem_fun( *this, & gEKGPrintDialog::OKcallback ) );
  CButton.signal_clicked().connect(
    mem_fun( *this, & gEKGPrintDialog::Ccallback ) );
  signal_key_press_event().connect( 
    mem_fun( *this, & gEKGPrintDialog::keyCallback ) );
  // Alle zeigen, damit die Gre bekannt ist.
  tCombo.show();
  vCombo.show();
  tfCButton.show();
  fName.show();
  OKButton.show();
  CButton.show();
  pName.show();
  pDate.show();
  tLabel.show();
  vLabel.show();
  nLabel.show();
  pnLabel.show();
  pdLabel.show();
  separator.show();
  bBox.show();
  table.show();
}




// Bei OK alle Daten bernehmen.
void gEKGPrintDialog::OKcallback()
{
  hide();
  ts = atof( tCombo.get_active_text().c_str() );
  vs = atof( vCombo.get_active_text().c_str() );
  toFile = tfCButton.get_active();
  fname = fName.get_text();
  pname = pName.get_text();
  pdate = pDate.get_text();
  state = true;
}




// Cancel gedrckt.
void gEKGPrintDialog::Ccallback()
{
  hide();
  state = false;
}


// Tastendrcke
gint gEKGPrintDialog::keyCallback( GdkEventKey * e )
{
  switch ( e->keyval )
  {
    case 0xff1b : // escape
      CButton.clicked();
      return true;
  }
  return false;
}



